/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.binaryfile;

import java.io.OutputStream;
import java.util.List;
import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.archive.ArchiveManagerConfiguration;
import de.ozgcloud.archive.file.OzgFile;
import de.ozgcloud.common.binaryfile.FileId;
import lombok.RequiredArgsConstructor;

@Service(ArchiveManagerConfiguration.BINARY_FILE_SERVICE_NAME)
@RequiredArgsConstructor
public class BinaryFileService {

	@Qualifier(ArchiveManagerConfiguration.BINARY_FILE_REMOTE_SERVICE_NAME)
	private final BinaryFileRemoteService binaryFileRemoteService;

	public Stream<OzgFile> getFiles(List<FileId> attachments) {
		return binaryFileRemoteService.getFiles(attachments);
	}

	public OzgFile getFile(FileId fileId) {
		return binaryFileRemoteService.getFile(fileId);
	}

	public void writeFileContent(FileId fileId, OutputStream outputStream) {
		binaryFileRemoteService.writeFileContent(fileId, outputStream);
	}

}
