/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.user;

import java.util.Optional;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.user.OzgCloudUserId;
import de.ozgcloud.apilib.user.OzgCloudUserProfileService;
import de.ozgcloud.archive.ArchiveManagerConfiguration;
import lombok.RequiredArgsConstructor;

@Service(ArchiveManagerConfiguration.USER_SERVICE_NAME)
@RequiredArgsConstructor
public class UserService {

	private static final String SYSTEM_USER_ID_PREFIX = "system";

	@Qualifier(ArchiveManagerConfiguration.OZGCLOUD_USER_PROFILE_SERVICE_NAME)
	private final OzgCloudUserProfileService grpcOzgCloudUserProfileService;

	@Qualifier(ArchiveManagerConfiguration.USER_PROFILE_MAPPER_NAME)
	private final UserProfileMapper mapper;

	public String getFullNameById(String userId) {
		// TODO (Story offen) es soll der Name des Systems geliefert werden, wenn kein
		// Mensch die Aktion ausgeführt hat
		return getById(userId).map(UserProfile::getFullName).orElse("automatisch");
	}

	public Optional<UserProfile> getById(String userId) {
		return Optional.of(userId).filter(id -> !id.startsWith(SYSTEM_USER_ID_PREFIX))
				.map(OzgCloudUserId::from)
				.map(grpcOzgCloudUserProfileService::getById)
				.map(mapper::fromOzgUserProfile);
	}

}
