/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.archivierung;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.mock.mockito.SpyBean;
import org.springframework.context.ApplicationEventPublisher;

import de.ozgcloud.archive.common.callcontext.CallContextUser;
import de.ozgcloud.command.Command;
import de.ozgcloud.command.CommandCreatedEventTestFactory;
import de.ozgcloud.command.CommandTestFactory;
import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.vorgang.callcontext.WithMockCustomUser;

@ITCase
@WithMockCustomUser
class ArchiveEventListenerITCase {

	@SpyBean
	private ArchiveEventListener eventListener;

	@Autowired
	private ApplicationEventPublisher publisher;

	@Nested
	class TestOnArchiveVorgang {

		private static final Command COMMAND = CommandTestFactory.createBuilder().order(ArchiveEventListener.ARCHIVE_VORGANG_ORDER).build();

		@Test
		void shouldReactOnOrder() {
			var event = CommandCreatedEventTestFactory.withCommand(COMMAND);

			publisher.publishEvent(event);

			verify(eventListener).onArchiveVorgangEvent(event);
		}

		@Test
		void shouldNotReactOnOtherOrder() {
			publisher.publishEvent(CommandCreatedEventTestFactory.withCommand(CommandTestFactory.createBuilder().order("OTHER").build()));

			verifyNoInteractions(eventListener);
		}
	}

	@Nested
	class TestOnVorgangLockedEvent {

		private static final Command COMMAND = CommandTestFactory.createBuilder()
				.createdByClientName(CallContextUser.ARCHIVE_MANAGER_CLIENT_NAME)
				.build();

		@Test
		void shouldReactOnOrder() {
			var event = VorgangLockedEventTestFactory.withCommand(COMMAND);
			doNothing().when(eventListener).onVorgangLockedEvent(any());

			publisher.publishEvent(event);

			verify(eventListener).onVorgangLockedEvent(event);
		}

		@Test
		void shouldNotReactOnOtherOrder() {
			publisher
					.publishEvent(VorgangLockedEventTestFactory.withCommand(CommandTestFactory.createBuilder().createdByClientName("OTHER").build()));

			verifyNoInteractions(eventListener);
		}
	}
}