/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.export;

import static org.assertj.core.api.Assertions.*;

import org.apache.commons.lang3.StringUtils;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class NamespacePrefixMapperTest {

	private XdomeaNamespacePrefixMapper prefixMapper = new XdomeaNamespacePrefixMapper();

	@DisplayName("Get preferred prefix")
	@Nested
	class TestGetPreferredPrefix {

		@Test
		void shouldReturnXdomeaPrefix() {
			var prefix = prefixMapper.getPreferredPrefix(XdomeaNamespacePrefixMapper.XDOMEA_NAMESPACE_URI, StringUtils.EMPTY, false);

			assertThat(prefix).isEqualTo(XdomeaNamespacePrefixMapper.XDOMEA_NAMESPACE_PREFIX);
		}

		@Test
		void shouldReturnSuggestion() {
			var prefix = prefixMapper.getPreferredPrefix("not existing", "suggestion", false);

			assertThat(prefix).isEqualTo("suggestion");
		}
	}

	@DisplayName("Get pre decrlared namespace uris")
	@Nested
	class TestGetPreDeclaredNamespaceUris {

		@Test
		void shouldHaveSize() {
			var uris = prefixMapper.getPreDeclaredNamespaceUris();

			assertThat(uris).hasSize(4);
		}

		@Test
		void shouldContainsDinspec() {
			var uris = prefixMapper.getPreDeclaredNamespaceUris();

			assertThat(uris).contains(XdomeaNamespacePrefixMapper.XDOMEA_NAMESPACE_DINSPEC_URI);
		}

		@Test
		void shouldContainsGml() {
			var uris = prefixMapper.getPreDeclaredNamespaceUris();

			assertThat(uris).contains(XdomeaNamespacePrefixMapper.XDOMEA_NAMESPACE_GML_URI);
		}

		@Test
		void shouldContainsXoevCode() {
			var uris = prefixMapper.getPreDeclaredNamespaceUris();

			assertThat(uris).contains(XdomeaNamespacePrefixMapper.XDOMEA_NAMESPACE_XOEV_CODE_URI);
		}

		@Test
		void shouldContainsXoevLx() {
			var uris = prefixMapper.getPreDeclaredNamespaceUris();

			assertThat(uris).contains(XdomeaNamespacePrefixMapper.XDOMEA_NAMESPACE_XOEV_LC_URI);
		}
	}
}