/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import de.xoev.xdomea.FeldType;

class ExportFelderTest {

	@Nested
	class TestCreateFeld {

		private static final FeldType FELD = ExportFelder.LEIKA_ID.createFeld();

		@Test
		void shouldHaveName() {
			assertThat(FELD.getName()).isEqualTo(ExportFelder.LEIKA_ID.getName());
		}

		@Test
		void shouldHaveBeschreibung() {
			assertThat(FELD.getBeschreibung()).isEqualTo(ExportFelder.LEIKA_ID.getBeschreibung());
		}

		@Test
		void shouldHaveDatentyp() {
			assertThat(FELD.getDatentyp().getCode()).isEqualTo(ExportFelder.LEIKA_ID.getDatentypCode());
		}

		@Test
		void shouldNotHaveWert() {
			assertThat(FELD.getWert()).isNull();
		}

		@Nested
		class MitWert {

			private static final String FELD_WERT = "123";

			@Test
			void shouldHaveWert() {
				var feld = ExportFelder.LEIKA_ID.createFeld(FELD_WERT);

				assertThat(feld.getWert()).isEqualTo(FELD_WERT);
			}
		}
	}

}